#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# License: MIT
# vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4:

from django.shortcuts import render_to_response
from django.template import RequestContext
from django.conf import settings
from django.core.mail import send_mail
from geelweb.django.contactform.models import ContactForm

def contact(request):
    """Displays the contact form and sends the email"""
    form = ContactForm(request.POST or None)
    if form.is_valid():
        subject = form.cleaned_data['subject']
        message = form.cleaned_data['message']
        sender = form.cleaned_data['sender']
        cc_myself = form.cleaned_data['cc_myself']

        recipients = settings.CONTACTFORM_RECIPIENTS
        if cc_myself:
            recipients.append(sender)

        send_mail(getattr(settings, "CONTACTFORM_SUBJECT_PREFIX", '') + subject, message, sender, recipients)

        return render_to_response(
            'contactform/thanks.html',
            {},
            context_instance=RequestContext(request))

    return render_to_response(
            'contactform/contact.html',
            {'form': form},
            context_instance=RequestContext(request))




# -*- coding: utf-8 -*-

from django.core import mail
from django.core.urlresolvers import reverse
from django.test import TestCase


class ContactTestCase(TestCase):
    def test_form_displayed(self):
        """ Tests than the contact.html template is displayed
        """
        resp = self.client.get(reverse('contact'))
        self.assertContains(resp, 'Send us a message', status_code=200)

    def test_form_validation(self):
        """ Tests than the error messages are displayed
        """
        resp = self.client.post(reverse('contact'), {
            'subject': '',
            'message': '',
            'sender': '',
            'cc_myself': ''})
        self.assertContains(resp, 'This field is required.', status_code=200)

    def test_mail_sent(self):
        """ Tests than the email is sent
        """
        resp = self.client.post(reverse('contact'), {
            'subject': 'Plop !',
            'message': 'This is my message content',
            'sender': 'me@example.com'})

        self.assertEqual(len(mail.outbox), 1)

        self.assertEqual(mail.outbox[0].subject, 'Plop !')

    def test_thanks_page_displayed(self):
        """ Tests than the thanks.html template is displayed
        """
        resp = self.client.post(reverse('contact'), {
            'subject': 'Plop !',
            'message': 'This is my message content',
            'sender': 'me@example.com'})
        self.assertContains(resp, 'Thanks for your message', status_code=200)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# License: MIT
# vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4:

__author__ = "Guillaume Luchet <guillaume@geelweb.org>"
__version__ = "0.2.1"

import os, sys
from setuptools import setup, find_packages

author_data = __author__.split(" ")
maintainer = " ".join(author_data[0:-1])
maintainer_email = author_data[-1]
README = open("README.rst").read()

setup(
    name="django-contactform",
    version=__version__,
    description="Django Contact Form Application",
    long_description=README,
    author=maintainer,
    author_email=maintainer_email,
    maintainer=maintainer,
    maintainer_email=maintainer_email,
    url="https://github.com/geelweb/geelweb-django-contactform",
    download_url="https://github.com/geelweb/geelweb-django-contactform/tarball/%s" % __version__,
    license="MIT",
    namespace_packages = ["geelweb", "geelweb.django"],
    packages=find_packages("src"),
    package_dir={"":"src"},
    package_data = {
        'geelweb.django.contactform': [
            'locale/*/LC_MESSAGES/*.po',
            'locale/*/LC_MESSAGES/*.mo'
        ],
    },
    keywords=['django', 'contact', 'form']
)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# License: MIT
# vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4:

"""Django contactform models"""

from django import forms
from django.utils.translation import ugettext as _

class ContactForm(forms.Form):
    """Contact form"""
    subject = forms.CharField(label=_('Subject'), max_length=100)
    message = forms.CharField(label=_('Message'), widget=forms.Textarea)
    sender = forms.EmailField(label=_('Sender email'))
    cc_myself = forms.BooleanField(label=_('Send me a copy'), required=False)

